################################## Load the libraries  ###################################

library (GEOquery)
library(Biobase)
library(affy)
library(oligo)
library(limma)
library(tidyverse)
library(Factoextra)
library(ggplot2)
library(ggfortify)
library(circlize)
library(AnnotationDbi)
library(mouse4302.db)
library(org.Mm.eg.db)
library(dplyr)
library(readr)
library(gplots) 
library(RColorBrewer) 
library(readxl) 
library(reshape2) 
library(ggpubr) 
library(clusterProfiler) 
library(enrichplot)
library(UpSetR) 
library(knitr)
library(kableExtra)
library(DT)

######################################  GSE41085  ########################################

setwd("~/Desktop/GEO-THz/GSE41085")


GSE41085 = getGEO("GSE41085")

sampleInfo <- pData(GSE41085[[1]])
head(sampleInfo)

design1 <- model.matrix(~0 + sampleInfo$`thz irradiation conditions:ch1`)
colnames(design1) <- c("THz", "Control")

gseID <- 'GSE41085'

# raw CEL files

raw <- oligo::read.celfiles(
  filenames = list.files('data/', pattern = 'CEL.gz', full.names = TRUE),
  sampleNames = gsub('\\.cel$', '', list.files('data/', pattern = 'CEL.gz')))


# RMA (the output is log transformed and quantile normalized)
gset <- rma(raw)

gset <- exprs(gset)
probes <- rownames(gset)
samIDs <- colnames(gset)

# annotate
annotLookup <- AnnotationDbi::select(mouse4302.db, keys = probes,
                                     columns = c('PROBEID', 'ENSEMBL', 'SYMBOL'))


# remove probes with any NA mapping
annotLookup <- annotLookup[!is.na(annotLookup$ENSEMBL) & !is.na(annotLookup$SYMBOL),]
annotLookup <- annotLookup[!duplicated(annotLookup$PROBEID),]


# look up the ensembl ID and gene symbol
probes <- probes[which(probes %in% annotLookup$PROBEID)]
gset <- gset[probes,]
all(rownames(gset)==probes)
all(probes == annotLookup[match(probes, annotLookup$PROBEID),'PROBEID'])
geneid <- annotLookup[match(probes, annotLookup$PROBEID),'SYMBOL']
ens <- annotLookup[match(probes, annotLookup$PROBEID),'ENSEMBL']

# finalise the dataset
rma.GSE41085 <- data.frame(ens = ens, symbol = geneid, gset)

# And average the expression value
aggdata.GSE41085 <- aggregate(rma.GSE41085[, -c(1,2)], by = list(Gene = rma.GSE41085$symbol), FUN = mean, na.rm = TRUE)
rownames(aggdata.GSE41085) <- aggdata.GSE41085[,1]


# Build contrast
fit <- lmFit(aggdata.GSE41085, design1)
fit$coefficients[1:10, ]

# Defining the contrast
cont.matrix <- makeContrasts(THzvsControl = Control - THz, levels = design1) 
fit2 <- contrasts.fit(fit, cont.matrix)

# Moderated t-test using eBayes() to obtain the pvalues
fit2 <- eBayes(fit2)

result2 <- limma::topTable(fit2, number = Inf, adjust = "BH", lfc = 0.5, coef = 1)  ### 07 DEGs

result2 <- subset(result2, select = c("symbol", "ENTREZID" , "adj.P.Val", "logFC" ))
write.table(result2, "diff_exp.txt",  row.names = FALSE, sep = "\t", quote = FALSE)


result2_GSE41085 <- subset(result2, select = c("Gene", "logFC" , "P.Value"))

write.table(result2_GSE41085, "result2_GSE41085.txt", row.names = FALSE, sep = "\t", quote = FALSE)

# DEGs SUBSETTING  

DEG_GSE41085  <- result2_GSE41085  %>% 
  dplyr::filter(abs(logFC)>0.5 & P.Value < 0.05) %>% 
  dplyr::pull(Gene)


######################################  GSE41084  ########################################


setwd("~/Desktop/GEO-THz/GSE41084")
getwd()


GSE41084 = getGEO("GSE41084")

sampleInfo <- pData(GSE41084[[1]])
head(sampleInfo)

design2 <- model.matrix(~0 + sampleInfo$`thz irradiation conditions:ch1`)
colnames(design2) <- c("THz", "Control")

gseID <- 'GSE41084'

# raw CEL files

raw <- oligo::read.celfiles(
  filenames = list.files('data/', pattern = 'CEL.gz', full.names = TRUE),
  sampleNames = gsub('\\.cel$', '', list.files('data/', pattern = 'CEL.gz')))


# RMA (the output is log transformed and quantile normalized)
gset <- rma(raw)


gset <- exprs(gset)
probes <- rownames(gset)
samIDs <- colnames(gset)

# annotate
annotLookup <- AnnotationDbi::select(mouse4302.db, keys = probes,
                                     columns = c('PROBEID', 'ENSEMBL', 'SYMBOL'))


# remove probes with any NA mapping
annotLookup <- annotLookup[!is.na(annotLookup$ENSEMBL) & !is.na(annotLookup$SYMBOL),]
annotLookup <- annotLookup[!duplicated(annotLookup$PROBEID),]


# look up the ensembl ID and gene symbol
probes <- probes[which(probes %in% annotLookup$PROBEID)]
gset <- gset[probes,]
all(rownames(gset)==probes)
all(probes == annotLookup[match(probes, annotLookup$PROBEID),'PROBEID'])
geneid <- annotLookup[match(probes, annotLookup$PROBEID),'SYMBOL']
ens <- annotLookup[match(probes, annotLookup$PROBEID),'ENSEMBL']

# finalise the dataset
rma.GSE41084 <- data.frame(ens = ens, symbol = geneid, gset)


# And average the expression value
aggdata.GSE41084 <- aggregate(rma.GSE41084[, -c(1,2)], by = list(Gene = rma.GSE41084$symbol), FUN = mean, na.rm = TRUE)
rownames(aggdata.GSE41084) <- aggdata.GSE41084[,1]


# Build contrast
fit <- lmFit(aggdata.GSE41084, design2)

# Defining the contrast
cont.matrix <- makeContrasts(THzvsControl = Control - THz, levels = design2) 
fit2 <- contrasts.fit(fit, cont.matrix)

# Moderated t-test using eBayes() to obtain the pvalues
fit2 <- eBayes(fit2, trend = TRUE)

result2 <- topTable(fit2, number = Inf, adjust = "BH", lfc = 0.5, coef = 1)

result2_GSE41084 <- subset(result2, select = c("Gene", "logFC" , "P.Value"))

write.table(result2_GSE41084, "result2_GSE41084.txt", row.names = FALSE, sep = "\t", quote = FALSE)

# DEGs SUBSETTING  

DEG_GSE41084  <- result2_GSE41084  %>% 
  dplyr::filter(abs(logFC)>0.5 & P.Value < 0.05) %>% 
  dplyr::pull(Gene)

######################################  GSE41083  ########################################

setwd("~/Desktop/GEO-THz/GSE41083")

GSE41083 = getGEO("GSE41083")

sampleInfo <- pData(GSE41083[[1]])
head(sampleInfo)

design3 <- model.matrix(~0 + sampleInfo$`thz irradiation conditions:ch1`)
colnames(design3) <- c("THz", "Control")

gseID <- 'GSE41083'

# raw CEL files

raw <- oligo::read.celfiles(
  filenames = list.files('data/', pattern = 'CEL.gz', full.names = TRUE),
  sampleNames = gsub('\\.cel$', '', list.files('data/', pattern = 'CEL.gz')))


# RMA (the output is log transformed and quantile normalized)
gset <- rma(raw)

gset <- exprs(gset)
probes <- rownames(gset)
samIDs <- colnames(gset)

# annotate
annotLookup <- AnnotationDbi::select(mouse4302.db, keys = probes,
                                     columns = c('PROBEID', 'ENSEMBL', 'SYMBOL'))


# remove probes with any NA mapping
annotLookup <- annotLookup[!is.na(annotLookup$ENSEMBL) & !is.na(annotLookup$SYMBOL),]
annotLookup <- annotLookup[!duplicated(annotLookup$PROBEID),]


# look up the ensembl ID and gene symbol
probes <- probes[which(probes %in% annotLookup$PROBEID)]
gset <- gset[probes,]
all(rownames(gset)==probes)
all(probes == annotLookup[match(probes, annotLookup$PROBEID),'PROBEID'])
geneid <- annotLookup[match(probes, annotLookup$PROBEID),'SYMBOL']
ens <- annotLookup[match(probes, annotLookup$PROBEID),'ENSEMBL']


# finalise the dataset
rma.GSE41083 <- data.frame(ens = ens, symbol = geneid, gset)

# And average the expression value
aggdata.GSE41083 <- aggregate(rma.GSE41083[, -c(1,2)], by = list(Gene = rma.GSE41083$symbol), FUN = mean, na.rm = TRUE)
rownames(aggdata.GSE41083) <- aggdata.GSE41083[,1]


# Build contrast
fit <- lmFit(aggdata.GSE41083, design3)

# Defining the contrast
cont.matrix <- makeContrasts(THzvsControl = Control - THz, levels = design3) 
fit2 <- contrasts.fit(fit, cont.matrix)

# Moderated t-test using eBayes() to obtain the pvalues
fit2 <- eBayes(fit2, trend = TRUE)

result2 <- topTable(fit2, number = Inf, adjust = "BH", lfc = 0.5, coef = 1)  

result2_GSE41083 <- subset(result2, select = c("Gene", "logFC" , "P.Value"))

write.table(result2_GSE41083, "result2_GSE41083.txt", row.names = FALSE, sep = "\t", quote = FALSE)

# DEGs SUBSETTING  

DEG_GSE41083  <- result2_GSE41083  %>% 
  dplyr::filter(abs(logFC)>0.5 & P.Value < 0.05) %>% 
  dplyr::pull(Gene)

######################################  GSE44671  ########################################

require(mogene10sttranscriptcluster.db)

GSE44671 = getGEO("GSE44671")

sampleInfo <- pData(GSE44671[[1]])

sampleInfo$`stress:ch1`

design4 <- model.matrix(~0 + sampleInfo$`stress:ch1`)
colnames(design4) <- c("Control", "THz")

gseID <- 'GSE44671'

# raw CEL files

message('--loading CEL files for ', gseID)
raw <- oligo::read.celfiles(
  filenames = list.files('data/', pattern = 'CEL.gz', full.names = TRUE),
  sampleNames = gsub('\\.cel$', '', list.files('data/', pattern = 'CEL.gz')))


# RMA 
gset <- rma(raw)


gset <- exprs(gset)
probes <- rownames(gset)
samIDs <- colnames(gset)


# Create annotatation lookup table
annotTable <- AnnotationDbi::select(mogene10sttranscriptcluster.db, keys = keys(mogene10sttranscriptcluster.db),
                                     column = c('PROBEID', 'ENSEMBL', 'SYMBOL', 'ENTREZID'),
                                     keytype = 'PROBEID')


# remove probes with any NA mapping
annotTable.filt <- annotTable[!is.na(annotTable$SYMBOL) & !is.na(annotLookup$ENSEMBL),]
annotTable.filt <- annotTable.filt[!duplicated(annotTable.filt$PROBEID),]

# look up the ensembl ID and gene symbol
probes <- probes[which(probes %in% annotTable.filt$PROBEID)]
gset <- gset[probes,]
all(rownames(gset)==probes)
all(probes == annotTable.filt[match(probes, annotTable.filt$PROBEID),'PROBEID'])
geneid <- annotTable.filt[match(probes, annotTable.filt$PROBEID),'SYMBOL']
ens <- annotTable.filt[match(probes, annotTable.filt$PROBEID),'ENSEMBL']


# finalise the dataset
rma.GSE44671 <- data.frame(ens = ens, symbol = geneid, gset)

# And average the expression value
aggdata.GSE44671 <- aggregate(rma.GSE44671[, -c(1,2)], by = list(Gene = rma.GSE44671$symbol), FUN = mean, na.rm = TRUE)
rownames(aggdata.GSE44671) <- aggdata.GSE44671[,1]


# Build contrast
fit <- lmFit(aggdata.GSE44671, design4)

# Defining the contrast
cont.matrix <- makeContrasts(THzvsControl = Control - THz, levels = design4)
fit2 <- contrasts.fit(fit, cont.matrix)


# Moderated t-test using eBayes() to obtain the pvalues
fit2 <- eBayes(fit2, trend = TRUE)

result2 <- topTable(fit2, number = Inf, adjust = "BH", lfc = 0.5, coef = 1)  ### 295 DEGs

result2_GSE44671 <- subset(result2, select = c("Gene", "logFC" , "P.Value"))

write.table(result2_GSE44671, "result2_GSE44671.txt", row.names = FALSE, sep = "\t", quote = FALSE)

# DEGs SUBSETTING  

DEG_GSE44671  <- result2_GSE44671  %>% 
  dplyr::filter(abs(logFC)>0.5 & P.Value < 0.05) %>% 
  dplyr::pull(Gene)
  
######################################  GSE178729  ########################################

setwd("~/Desktop/GEO-THz/GSE178729")

series <- "GSE178729"
platform <- "GPL21163"

gse = getGEO("GSE178729")

gse <- gse[[1]]

pData(gse)

exprs(gse)
summary(exprs(gse))

## Log2 normalization
exprs(gse) <- log2(exprs(gse))
summary(exprs(gse))


sampleInfo <- pData(gse)

sampleInfo$`treatment:ch1` 

## Build design
design <- cbind(Control = c(rep(1, 3), rep(0, 3)), THz = c(rep(0, 3), rep(1, 3)))  

## calculate the 25th percentile expression level
cutoff <- quantile(exprs(gse), 0.25)

## TRUE or FALSE for whether each gene is "expressed" in each sample
is_expressed <- exprs(gse) > cutoff

# Identify genes expressed in more than 3 samples
keep <- rowSums(is_expressed) > 3

## check how many genes are removed / retained.
table(keep)

## subset to just those expressed genes
gse <- gse[keep,]

## Fitting the coefficients
fit <- lmFit(exprs(gse), design)

## Making comparisons between samples
contrasts <- makeContrasts(THz - Control, levels = design)

fit2 <- contrasts.fit(fit, contrasts)
fit2 <- eBayes(fit2)

## Annotate
library(org.Mm.eg.db)
anno <- fData(gse)


anno <- anno[, c("GENE_SYMBOL", "ENSEMBL_ID")]

# remove probes with any NA mapping
anno <- anno[!is.na(anno$ENSEMBL_ID) & !is.na(anno$GENE_SYMBOL),] # Does not work, empty columns
anno <- anno[!duplicated(anno$ENSEMBL_ID) & !duplicated(anno$GENE_SYMBOL),]


result2 <- limma::topTable(fit2, number = Inf, adjust = "BH", lfc = 0.5, coef = 1)  

result2 <- result2[!is.na(result2$ENSEMBL_ID) & !is.na(result2$GENE_SYMBOL),] 

result2_GSE178729 <- subset(result2, select = c("GENE_SYMBOL", "logFC" , "P.Value"))

write.table(result2_GSE178729, "result2_GSE178729.txt", row.names = FALSE, sep = "\t", quote = FALSE)

# DEGs SUBSETTING  

DEG_GSE178729  <- result2_GSE178729  %>% 
  dplyr::filter(abs(logFC)>0.5 & P.Value < 0.05) %>% 
  dplyr::pull(Gene)

################################## META-ANALYSIS #########################################

## Merge the DEGs

DEG_GSE44671.m <- as.numeric(all %in% DEG_GSE44671) 
DEG_GSE178729.m <- as.numeric(all %in% DEG_GSE178729)
DEG_GSE41083.m <- as.numeric(all %in% DEG_GSE41083) 
DEG_GSE41084.m <- as.numeric(all %in% DEG_GSE41084)
DEG_GSE41085.m <- as.numeric(all %in% DEG_GSE41085)


all.df <- data.frame("Kim_GSE44671" = DEG_GSE44671.m, 
                     "Zhao_GSE178729" = DEG_GSE178729.m, 
                     "Alexandrov_GSE41083" = DEG_GSE41083.m, 
                     "Alexandrov_GSE41084" = DEG_GSE41084.m, 
                     "Alexandrov_GSE41085" = DEG_GSE41085.m,
                     row.names=all)


upset(all.df)

# Save as JPEG

jpeg(file="Figure 2. UpSet plot to visualize the overlap between sets of differentially expressed genes.jpeg",
     width = 12, height = 10, units = "in", res = 300)
upset(all.df)
dev.off()


DEGAll <- unique(c(DEG_GSE44671, DEG_GSE178729, DEG_GSE41083, DEG_GSE41084, DEG_GSE41085))

## Enrichment in C5 gene ontology

# Get the gene sets and wrangle
gene_sets <- msigdbr(species = "Mus musculus", category = "C5") #
gene_sets <- gene_sets %>%
  dplyr::select(gs_name, gene_symbol) # extract gene set names and gene set symbol

# Run the over-representation analysis
set.seed(1994)

GO <- enricher(gene = DEGAll,
               TERM2GENE = gene_sets)


GO.s <- GO
GO.df <-GO.s@result%>%
  # separate ratios into 2 columns of data
  separate(BgRatio, into = c("size.term", "size.category"), sep = "/") %>%
  separate(GeneRatio, into= c("size.overlap.term", "size.overlap.category"),
           sep = "/") %>%
  # convert to numeric
  mutate_at(vars("size.term", "size.category", "size.overlap.term", 
                 "size.overlap.category"),
            as.numeric) %>%
  # calculate k/k
  mutate("k.k" = size.overlap.term/size.term)        

# Visualize results
jpeg(file="Figure 3. Significant genes enriched from MsigDB (c5 canonical pathways).jpeg",
     width = 12, height = 10, units = "in", res = 300)

dev.off()

GO.df %>%
  filter(p.adjust <= 0.01) %>%        
  # Beautify description by removing _ and HALLMARK
  mutate(Description = gsub("HALLMARK_","", Description),
         Description = gsub("_"," ", Description)) %>%
  ggplot(aes(x = reorder(Description, k.k),
             y = k.k)) +
  geom_col() +
  theme_classic() +
  coord_flip() +
  labs(x="Genes set",
       y="Significant genes in set/Total genes in set (nk/k)",
       title = "Significant genes enrinched using C5 collection from MSigDB")

dev.off()

jpeg(file="Figure 4. Dotplot enrichment of differentially expressed genes.jpeg",
     width = 12, height = 10, units = "in", res = 300)

dotplot(GO)

dev.off()

jpeg(file="Figure 5. CnetPlot genes enriched from MsigDB.jpeg",
     width = 12, height = 10, units = "in", res = 300)

cnetplot(GO,
            categorySize="count",
            showCategory = 10,
            layout = "kk",
            vertex.label.font=7,
            colorEdge = TRUE)

dev.off()

##########################################################################################


















